@@ -22,6 +22,15 @@ class Route:
     name: str = field(init=False)
     line_description: list[str] = field(init=False)
 
+    def __repr__(self) -> str:
+        """Return the representation."""
+        cls_name = type(self).__name__
+        return f"{cls_name}(id={self.route_id}, name={self.name})"
+
+    def __hash__(self) -> int:
+        """Return the hash."""
+        return hash(self.route_id)
+
     def __post_init__(self) -> None:
         """Post init."""
         self.route_id = self.data["RouteID"]
