@@ -32,6 +32,15 @@ class Stop:
     name: str = field(init=False)
     route_ids: list[str] = field(init=False)
 
+    def __repr__(self) -> str:
+        """Return the representation."""
+        cls_name = type(self).__name__
+        return f"{cls_name}(code={self.stop_id}, name={self.name})"
+
+    def __hash__(self) -> int:
+        """Return the hash."""
+        return hash(self.stop_id)
+
     def __post_init__(self) -> None:
         """Post init."""
         if isinstance(self.data["StopID"], str):
